Cliquet
=======

|travis| |master-coverage| |readthedocs|

.. |travis| image:: https://travis-ci.org/mozilla-services/cliquet.svg?branch=master
    :target: https://travis-ci.org/mozilla-services/cliquet

.. |readthedocs| image:: https://readthedocs.org/projects/cliquet/badge/?version=latest
    :target: http://cliquet.readthedocs.org/en/latest/
    :alt: Documentation Status

.. |master-coverage| image::
    https://coveralls.io/repos/mozilla-services/cliquet/badge.png?branch=master
    :alt: Coverage
    :target: https://coveralls.io/r/mozilla-services/cliquet


*Cliquet* is a toolkit to ease the implementation of HTTP microservices,
such as data-driven REST APIs.

* `Online documentation <http://cliquet.readthedocs.org/en/latest/>`_
* `Issue tracker <https://github.com/mozilla-services/cliquet/issues>`_
* `Contributing <http://cliquet.readthedocs.org/en/latest/contributing.html>`_
* `Talk at PyBCN <http://mozilla-services.github.io/cliquet/talks/2015.07.pybcn/>`_
